==> darcs-2.18.5-141-x86_64.pkg.tar.zst: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 darcs
version:              2.18.5
visibility:           public
id:                   darcs-2.18.5-Hq0TE4R6g1FETu6KKaNirW
key:                  darcs-2.18.5-Hq0TE4R6g1FETu6KKaNirW
license:              GPL-2.0-or-later
maintainer:           <darcs-devel@darcs.net>
author:               David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability:            Experimental
homepage:             http://darcs.net/
synopsis:             a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:

    * Distributed: Darcs was one of the first revision control
    systems in which every user has access to the full command
    set, removing boundaries between server and client or
    committer and non-committers.

    * Interactive: Darcs is easy to learn and efficient to use
    because it asks you questions in response to simple
    commands, giving you choices in your work flow. You can
    choose to record one change in a file, while ignoring
    another. As you update from upstream, you can review each
    patch, picking and choosing which patches are appropriate.

    * Smart: Darcs is different from most revision control
    systems in that it is based on the notion of change (or
    patch), rather than version. An underlying algebra of
    patches determines whether changes can be re-ordered. The
    laws of this algebra guarantee that the result of merging
    depends only on the final set of patches applied in a
    repository and not on their order.

    * Simple: As a consequence, Darcs offers a conceptually
    simpler view of the state of a repository: it is given by
    the set of patches it contains. Pulling and pushing
    patches merely transfers them from one set to another. So
    called "cherry-picking" is the default mode of operation,
    and it fully preserves the identity of patches.

category:             Development
abi:                  b047bd71b122f6ff04355982e5b51876
exposed:              True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Annotate.Class
    Darcs.Patch.Apply Darcs.Patch.ApplyMonad Darcs.Patch.Bracketed
    Darcs.Patch.Bundle Darcs.Patch.Choices Darcs.Patch.Commute
    Darcs.Patch.CommuteFn Darcs.Patch.CommuteNoConflicts
    Darcs.Patch.Conflict Darcs.Patch.Debug Darcs.Patch.Depends
    Darcs.Patch.Effect Darcs.Patch.FileHunk Darcs.Patch.Format
    Darcs.Patch.FromPrim Darcs.Patch.Ident Darcs.Patch.Index.Monad
    Darcs.Patch.Index.Types Darcs.Patch.Info Darcs.Patch.Inspect
    Darcs.Patch.Invert Darcs.Patch.Invertible Darcs.Patch.Match
    Darcs.Patch.Merge Darcs.Patch.Named Darcs.Patch.Object
    Darcs.Patch.PatchInfoAnd Darcs.Patch.Permutations Darcs.Patch.Prim
    Darcs.Patch.Prim.Canonize Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.Coalesce Darcs.Patch.Prim.FileUUID
    Darcs.Patch.Prim.FileUUID.Apply Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.Named
    Darcs.Patch.Prim.V1 Darcs.Patch.Prim.V1.Apply
    Darcs.Patch.Prim.V1.Coalesce Darcs.Patch.Prim.V1.Commute
    Darcs.Patch.Prim.V1.Core Darcs.Patch.Prim.V1.Details
    Darcs.Patch.Prim.V1.Mangle Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.WithName
    Darcs.Patch.Progress Darcs.Patch.Read Darcs.Patch.Rebase.Change
    Darcs.Patch.Rebase.Fixup Darcs.Patch.Rebase.Legacy.Item
    Darcs.Patch.Rebase.Legacy.Wrapped Darcs.Patch.Rebase.Name
    Darcs.Patch.Rebase.PushFixup Darcs.Patch.Rebase.Suspended
    Darcs.Patch.RegChars Darcs.Patch.Repair Darcs.Patch.RepoPatch
    Darcs.Patch.Set Darcs.Patch.Show Darcs.Patch.Split
    Darcs.Patch.Summary Darcs.Patch.SummaryData
    Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
    Darcs.Patch.Unwind Darcs.Patch.V1 Darcs.Patch.V1.Apply
    Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Prim
    Darcs.Patch.V1.Read Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing
    Darcs.Patch.V2 Darcs.Patch.V2.Non Darcs.Patch.V2.Prim
    Darcs.Patch.V2.RepoPatch Darcs.Patch.V3 Darcs.Patch.V3.Contexted
    Darcs.Patch.V3.Core Darcs.Patch.V3.Resolution Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Maybe
    Darcs.Patch.Witnesses.Ordered Darcs.Patch.Witnesses.Sealed
    Darcs.Patch.Witnesses.Show Darcs.Patch.Witnesses.Unsafe
    Darcs.Patch.Witnesses.WZipper Darcs.Prelude Darcs.Repository
    Darcs.Repository.ApplyPatches Darcs.Repository.Clone
    Darcs.Repository.Create Darcs.Repository.Diff
    Darcs.Repository.Flags Darcs.Repository.Format
    Darcs.Repository.Hashed Darcs.Repository.Identify
    Darcs.Repository.InternalTypes Darcs.Repository.Inventory
    Darcs.Repository.Inventory.Format Darcs.Repository.Job
    Darcs.Repository.Match Darcs.Repository.Merge Darcs.Repository.Old
    Darcs.Repository.Packs Darcs.Repository.PatchIndex
    Darcs.Repository.Paths Darcs.Repository.Pending
    Darcs.Repository.Prefs Darcs.Repository.Pristine
    Darcs.Repository.Rebase Darcs.Repository.Repair
    Darcs.Repository.Resolution Darcs.Repository.State
    Darcs.Repository.Transaction Darcs.Repository.Traverse
    Darcs.Repository.Unrevert Darcs.Repository.Working
    Darcs.Test.TestOnly Darcs.UI.ApplyPatches Darcs.UI.Commands
    Darcs.UI.Commands.Add Darcs.UI.Commands.Amend
    Darcs.UI.Commands.Annotate Darcs.UI.Commands.Apply
    Darcs.UI.Commands.Clone Darcs.UI.Commands.Convert
    Darcs.UI.Commands.Convert.Darcs2 Darcs.UI.Commands.Convert.Export
    Darcs.UI.Commands.Convert.Import Darcs.UI.Commands.Convert.Util
    Darcs.UI.Commands.Diff Darcs.UI.Commands.Dist
    Darcs.UI.Commands.GZCRCs Darcs.UI.Commands.Help
    Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.Test.Impl
    Darcs.UI.Commands.TransferMode Darcs.UI.Commands.Unrecord
    Darcs.UI.Commands.Unrevert Darcs.UI.Commands.Util
    Darcs.UI.Commands.WhatsNew Darcs.UI.Completion Darcs.UI.Defaults
    Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags Darcs.UI.Options
    Darcs.UI.Options.All Darcs.UI.Options.Core Darcs.UI.Options.Flags
    Darcs.UI.Options.Iso Darcs.UI.Options.Markdown
    Darcs.UI.Options.Matching Darcs.UI.Options.Util
    Darcs.UI.PatchHeader Darcs.UI.PrintPatch Darcs.UI.Prompt
    Darcs.UI.RunCommand Darcs.UI.RunHook Darcs.UI.SelectChanges
    Darcs.UI.TestChanges Darcs.UI.TheCommands Darcs.UI.Usage
    Darcs.Util.AtExit Darcs.Util.ByteString Darcs.Util.Cache
    Darcs.Util.CommandLine Darcs.Util.Compat Darcs.Util.DateMatcher
    Darcs.Util.DateTime Darcs.Util.Diff Darcs.Util.Diff.Myers
    Darcs.Util.Diff.Patience Darcs.Util.Encoding Darcs.Util.English
    Darcs.Util.Exception Darcs.Util.Exec Darcs.Util.File
    Darcs.Util.Global Darcs.Util.Graph Darcs.Util.HTTP Darcs.Util.Hash
    Darcs.Util.Index Darcs.Util.IndexedMonad Darcs.Util.IsoDate
    Darcs.Util.Lock Darcs.Util.Parser Darcs.Util.Path
    Darcs.Util.Printer Darcs.Util.Printer.Color Darcs.Util.Progress
    Darcs.Util.Prompt Darcs.Util.Ratified Darcs.Util.Regex
    Darcs.Util.Show Darcs.Util.SignalHandler Darcs.Util.Ssh
    Darcs.Util.StrictIdentity Darcs.Util.Tree Darcs.Util.Tree.Hashed
    Darcs.Util.Tree.Monad Darcs.Util.Tree.Plain Darcs.Util.URL
    Darcs.Util.ValidHash Darcs.Util.Workaround

hidden-modules:       Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/darcs-2.18.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/darcs-2.18.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/darcs-2.18.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/darcs
hs-libraries:         HSdarcs-2.18.5-Hq0TE4R6g1FETu6KKaNirW
depends:
    array-0.5.4.0 async-2.2.5-JHW95XcL1gYGEBHblGmePL
    attoparsec-0.14.4-6kRuW0kw4gG3rg1QrsDffs base-4.17.2.1
    base16-bytestring-1.0.2.0-AZR9Ev6hMd0IJX97hPwFaq binary-0.8.9.1
    bytestring-0.11.5.3 conduit-1.3.6.1-P2VVzWMvOMICi7Nj7BTmx
    constraints-0.14.2-IG2Q4hGIX9I3iciCwIxetH containers-0.6.7
    crypton-connection-0.4.4-4irtxig4UtYEvTUVCnwCkX
    cryptonite-0.30-AcWxXKG74F533fhikP0ty7
    data-default-0.7.1.2-434WfftxN7fJEVVCTZ9w4g
    data-ordlist-0.4.7.0-4hH2NjRHl6QGJGwQ9bkbTA directory-1.3.7.1
    exceptions-0.10.5 fgl-5.8.3.0-A1UW0yVTeCm7Wb4JnvFCcG
    filepath-1.4.2.2 hashable-1.4.5.0-DrXzgEMDRcV8gNOMGO5wPZ
    haskeline-0.8.2 html-1.0.1.2-J6DAJfvF1D3ECsZlmS8hoI
    http-client-tls-0.3.6.4-KN3JTiWE2EI1kyisYRtf57
    http-conduit-2.3.9.1-9RvHGJGxwHHJpUO7Zqiogv
    http-types-0.12.4-9tb655S6p8NAIcFLCK3aeD
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mmap-0.5.9-Elwtwd4pUdW5gAqAC4PwUa mtl-2.2.2
    network-3.1.4.0-BeHm9PhAGW35QMcXomVSuT
    network-uri-2.6.4.2-FpQrzNLQnEFHV7gxKif8bC
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 parsec-3.1.16.1
    process-1.6.18.0 regex-applicative-0.3.4-FlD6YyvmFqT3npQa4T2tr4
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
    regex-tdfa-1.3.2.4-H7zmkJvyPWEApzv9Yii17i
    safe-0.3.21-2QfDol6D5mJHd9hpTIyjO0 stm-2.5.1.0
    tar-0.5.1.1-4ecIBITdtZIFxVtuzYCU4k
    temporary-1.3-J74qUD22gWeKClETiHEU0b
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A terminfo-0.4.1.5
    text-2.0.2 time-1.12.2 tls-2.0.6-HKFXOGFMblLEtuEFCBgiDy
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.4.1-8Y7lpXTSloK7vqVswTol3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-LmFi28PTaN7DJJszRwFTiC
    zip-archive-0.4.3.2-FeaNVuPkMdL1XZChLsYmAy
    zlib-0.7.0.0-GOInNFOI3XL1A6Gv5OWDAq

haddock-interfaces:   /usr/share/doc/darcs/html/darcs.haddock
haddock-html:         /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> darcs-2.18.5-142-x86_64.pkg.tar.zst: usr/share/haskell/register/darcs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 darcs
version:              2.18.5
visibility:           public
id:                   darcs-2.18.5-LZ9lSDt52yPAyeXpsgwAAQ
key:                  darcs-2.18.5-LZ9lSDt52yPAyeXpsgwAAQ
license:              GPL-2.0-or-later
maintainer:           <darcs-devel@darcs.net>
author:               David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
stability:            Experimental
homepage:             http://darcs.net/
synopsis:             a distributed, interactive, smart revision control system
description:
    Darcs is a free, open source revision control
    system. It is:

    * Distributed: Darcs was one of the first revision control
    systems in which every user has access to the full command
    set, removing boundaries between server and client or
    committer and non-committers.

    * Interactive: Darcs is easy to learn and efficient to use
    because it asks you questions in response to simple
    commands, giving you choices in your work flow. You can
    choose to record one change in a file, while ignoring
    another. As you update from upstream, you can review each
    patch, picking and choosing which patches are appropriate.

    * Smart: Darcs is different from most revision control
    systems in that it is based on the notion of change (or
    patch), rather than version. An underlying algebra of
    patches determines whether changes can be re-ordered. The
    laws of this algebra guarantee that the result of merging
    depends only on the final set of patches applied in a
    repository and not on their order.

    * Simple: As a consequence, Darcs offers a conceptually
    simpler view of the state of a repository: it is given by
    the set of patches it contains. Pulling and pushing
    patches merely transfers them from one set to another. So
    called "cherry-picking" is the default mode of operation,
    and it fully preserves the identity of patches.

category:             Development
abi:                  a68e92fff9a7c486866eeffd02e52622
exposed:              True
exposed-modules:
    Darcs.Patch Darcs.Patch.Annotate Darcs.Patch.Annotate.Class
    Darcs.Patch.Apply Darcs.Patch.ApplyMonad Darcs.Patch.Bracketed
    Darcs.Patch.Bundle Darcs.Patch.Choices Darcs.Patch.Commute
    Darcs.Patch.CommuteFn Darcs.Patch.CommuteNoConflicts
    Darcs.Patch.Conflict Darcs.Patch.Debug Darcs.Patch.Depends
    Darcs.Patch.Effect Darcs.Patch.FileHunk Darcs.Patch.Format
    Darcs.Patch.FromPrim Darcs.Patch.Ident Darcs.Patch.Index.Monad
    Darcs.Patch.Index.Types Darcs.Patch.Info Darcs.Patch.Inspect
    Darcs.Patch.Invert Darcs.Patch.Invertible Darcs.Patch.Match
    Darcs.Patch.Merge Darcs.Patch.Named Darcs.Patch.Object
    Darcs.Patch.PatchInfoAnd Darcs.Patch.Permutations Darcs.Patch.Prim
    Darcs.Patch.Prim.Canonize Darcs.Patch.Prim.Class
    Darcs.Patch.Prim.Coalesce Darcs.Patch.Prim.FileUUID
    Darcs.Patch.Prim.FileUUID.Apply Darcs.Patch.Prim.FileUUID.Coalesce
    Darcs.Patch.Prim.FileUUID.Commute Darcs.Patch.Prim.FileUUID.Core
    Darcs.Patch.Prim.FileUUID.Details
    Darcs.Patch.Prim.FileUUID.ObjectMap Darcs.Patch.Prim.FileUUID.Read
    Darcs.Patch.Prim.FileUUID.Show Darcs.Patch.Prim.Named
    Darcs.Patch.Prim.V1 Darcs.Patch.Prim.V1.Apply
    Darcs.Patch.Prim.V1.Coalesce Darcs.Patch.Prim.V1.Commute
    Darcs.Patch.Prim.V1.Core Darcs.Patch.Prim.V1.Details
    Darcs.Patch.Prim.V1.Mangle Darcs.Patch.Prim.V1.Read
    Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.WithName
    Darcs.Patch.Progress Darcs.Patch.Read Darcs.Patch.Rebase.Change
    Darcs.Patch.Rebase.Fixup Darcs.Patch.Rebase.Legacy.Item
    Darcs.Patch.Rebase.Legacy.Wrapped Darcs.Patch.Rebase.Name
    Darcs.Patch.Rebase.PushFixup Darcs.Patch.Rebase.Suspended
    Darcs.Patch.RegChars Darcs.Patch.Repair Darcs.Patch.RepoPatch
    Darcs.Patch.Set Darcs.Patch.Show Darcs.Patch.Split
    Darcs.Patch.Summary Darcs.Patch.SummaryData
    Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
    Darcs.Patch.Unwind Darcs.Patch.V1 Darcs.Patch.V1.Apply
    Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Prim
    Darcs.Patch.V1.Read Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing
    Darcs.Patch.V2 Darcs.Patch.V2.Non Darcs.Patch.V2.Prim
    Darcs.Patch.V2.RepoPatch Darcs.Patch.V3 Darcs.Patch.V3.Contexted
    Darcs.Patch.V3.Core Darcs.Patch.V3.Resolution Darcs.Patch.Viewing
    Darcs.Patch.Witnesses.Eq Darcs.Patch.Witnesses.Maybe
    Darcs.Patch.Witnesses.Ordered Darcs.Patch.Witnesses.Sealed
    Darcs.Patch.Witnesses.Show Darcs.Patch.Witnesses.Unsafe
    Darcs.Patch.Witnesses.WZipper Darcs.Prelude Darcs.Repository
    Darcs.Repository.ApplyPatches Darcs.Repository.Clone
    Darcs.Repository.Create Darcs.Repository.Diff
    Darcs.Repository.Flags Darcs.Repository.Format
    Darcs.Repository.Hashed Darcs.Repository.Identify
    Darcs.Repository.InternalTypes Darcs.Repository.Inventory
    Darcs.Repository.Inventory.Format Darcs.Repository.Job
    Darcs.Repository.Match Darcs.Repository.Merge Darcs.Repository.Old
    Darcs.Repository.Packs Darcs.Repository.PatchIndex
    Darcs.Repository.Paths Darcs.Repository.Pending
    Darcs.Repository.Prefs Darcs.Repository.Pristine
    Darcs.Repository.Rebase Darcs.Repository.Repair
    Darcs.Repository.Resolution Darcs.Repository.State
    Darcs.Repository.Transaction Darcs.Repository.Traverse
    Darcs.Repository.Unrevert Darcs.Repository.Working
    Darcs.Test.TestOnly Darcs.UI.ApplyPatches Darcs.UI.Commands
    Darcs.UI.Commands.Add Darcs.UI.Commands.Amend
    Darcs.UI.Commands.Annotate Darcs.UI.Commands.Apply
    Darcs.UI.Commands.Clone Darcs.UI.Commands.Convert
    Darcs.UI.Commands.Convert.Darcs2 Darcs.UI.Commands.Convert.Export
    Darcs.UI.Commands.Convert.Import Darcs.UI.Commands.Convert.Util
    Darcs.UI.Commands.Diff Darcs.UI.Commands.Dist
    Darcs.UI.Commands.GZCRCs Darcs.UI.Commands.Help
    Darcs.UI.Commands.Init Darcs.UI.Commands.Log
    Darcs.UI.Commands.MarkConflicts Darcs.UI.Commands.Move
    Darcs.UI.Commands.Optimize Darcs.UI.Commands.Pull
    Darcs.UI.Commands.Push Darcs.UI.Commands.Rebase
    Darcs.UI.Commands.Record Darcs.UI.Commands.Remove
    Darcs.UI.Commands.Repair Darcs.UI.Commands.Replace
    Darcs.UI.Commands.Revert Darcs.UI.Commands.Rollback
    Darcs.UI.Commands.Send Darcs.UI.Commands.SetPref
    Darcs.UI.Commands.Show Darcs.UI.Commands.ShowAuthors
    Darcs.UI.Commands.ShowContents Darcs.UI.Commands.ShowDependencies
    Darcs.UI.Commands.ShowFiles Darcs.UI.Commands.ShowIndex
    Darcs.UI.Commands.ShowPatchIndex Darcs.UI.Commands.ShowRepo
    Darcs.UI.Commands.ShowTags Darcs.UI.Commands.Tag
    Darcs.UI.Commands.Test Darcs.UI.Commands.Test.Impl
    Darcs.UI.Commands.TransferMode Darcs.UI.Commands.Unrecord
    Darcs.UI.Commands.Unrevert Darcs.UI.Commands.Util
    Darcs.UI.Commands.WhatsNew Darcs.UI.Completion Darcs.UI.Defaults
    Darcs.UI.Email Darcs.UI.External Darcs.UI.Flags Darcs.UI.Options
    Darcs.UI.Options.All Darcs.UI.Options.Core Darcs.UI.Options.Flags
    Darcs.UI.Options.Iso Darcs.UI.Options.Markdown
    Darcs.UI.Options.Matching Darcs.UI.Options.Util
    Darcs.UI.PatchHeader Darcs.UI.PrintPatch Darcs.UI.Prompt
    Darcs.UI.RunCommand Darcs.UI.RunHook Darcs.UI.SelectChanges
    Darcs.UI.TestChanges Darcs.UI.TheCommands Darcs.UI.Usage
    Darcs.Util.AtExit Darcs.Util.ByteString Darcs.Util.Cache
    Darcs.Util.CommandLine Darcs.Util.Compat Darcs.Util.DateMatcher
    Darcs.Util.DateTime Darcs.Util.Diff Darcs.Util.Diff.Myers
    Darcs.Util.Diff.Patience Darcs.Util.Encoding Darcs.Util.English
    Darcs.Util.Exception Darcs.Util.Exec Darcs.Util.File
    Darcs.Util.Global Darcs.Util.Graph Darcs.Util.HTTP Darcs.Util.Hash
    Darcs.Util.Index Darcs.Util.IndexedMonad Darcs.Util.IsoDate
    Darcs.Util.Lock Darcs.Util.Parser Darcs.Util.Path
    Darcs.Util.Printer Darcs.Util.Printer.Color Darcs.Util.Progress
    Darcs.Util.Prompt Darcs.Util.Ratified Darcs.Util.Regex
    Darcs.Util.Show Darcs.Util.SignalHandler Darcs.Util.Ssh
    Darcs.Util.StrictIdentity Darcs.Util.Tree Darcs.Util.Tree.Hashed
    Darcs.Util.Tree.Monad Darcs.Util.Tree.Plain Darcs.Util.URL
    Darcs.Util.ValidHash Darcs.Util.Workaround

hidden-modules:       Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/darcs-2.18.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/darcs-2.18.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/darcs-2.18.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/darcs
hs-libraries:         HSdarcs-2.18.5-LZ9lSDt52yPAyeXpsgwAAQ
depends:
    array-0.5.4.0 async-2.2.5-BfPrxOOBs2Z6bEyvXKfM0q
    attoparsec-0.14.4-D7CECqktDgS2fYWStxbJq3 base-4.17.2.1
    base16-bytestring-1.0.2.0-6gnnhNAVOchGQBiiZZP74i binary-0.8.9.1
    bytestring-0.11.5.3 conduit-1.3.6.1-Iv674JaqEE17PR7slCoUfp
    constraints-0.14.2-8OMgZL2NYPT3ss0gOjxCmU containers-0.6.7
    crypton-connection-0.4.4-Ab8v787zCCYJ26NhXbMkEl
    cryptonite-0.30-Bo5JLza2cX2Fl8kPLOzYXJ
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    data-ordlist-0.4.7.0-4hH2NjRHl6QGJGwQ9bkbTA directory-1.3.7.1
    exceptions-0.10.5 fgl-5.8.3.0-HB304WeKiosDGhHcaUgJEX
    filepath-1.4.2.2 hashable-1.4.5.0-FUZ3820cmTgAr6H2g2EQN7
    haskeline-0.8.2 html-1.0.1.2-J6DAJfvF1D3ECsZlmS8hoI
    http-client-tls-0.3.6.4-3SOG6pMBD126OroBvnbwcp
    http-conduit-2.3.9.1-E073iTimlWyAaR79mDpECY
    http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mmap-0.5.9-Elwtwd4pUdW5gAqAC4PwUa mtl-2.2.2
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    network-uri-2.6.4.2-8swvJWOy75N7pbfI8WzbN
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 parsec-3.1.16.1
    process-1.6.18.0 regex-applicative-0.3.4-JOrPAIm2SZfKQAlxU8lw3E
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
    regex-tdfa-1.3.2.4-KR4bJeAvhxe7xzLSY8hs1u
    safe-0.3.21-6M2s73s6VIBE0aNh1wWxu0 stm-2.5.1.0
    tar-0.5.1.1-DGeka7VXNBJ12V9J6H5caF
    temporary-1.3-IuvCcNxKbgM9H8NbQNEe0S
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A terminfo-0.4.1.5
    text-2.0.2 time-1.12.2 tls-2.0.6-G1OfOfoVD5SESE7B79WJMM
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.4.1-51QWcgHKY9Q2M4gdNfLh1f
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg
    zip-archive-0.4.3.2-5s6UP7erHPJ4ZzDGvXywNZ
    zlib-0.7.0.0-LNxfZD2yBOpG9CUE6LYKNw

haddock-interfaces:   /usr/share/doc/darcs/html/darcs.haddock
haddock-html:         /usr/share/doc/darcs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
